==> kdepimlibs-4.2.4-i586-P2.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libgpgme++.so.2 )
( cd opt/kde/lib ; ln -sf libgpgme++.so.2.0.2 libgpgme++.so.2 )
( cd opt/kde/lib ; rm -rf libgpgme++.so )
( cd opt/kde/lib ; ln -sf libgpgme++.so.2 libgpgme++.so )
( cd opt/kde/lib ; rm -rf libgpgme++-pthread.so.2 )
( cd opt/kde/lib ; ln -sf libgpgme++-pthread.so.2.0.2 libgpgme++-pthread.so.2 )
( cd opt/kde/lib ; rm -rf libgpgme++-pthread.so )
( cd opt/kde/lib ; ln -sf libgpgme++-pthread.so.2 libgpgme++-pthread.so )
( cd opt/kde/lib ; rm -rf libgpgme++-pth.so.2 )
( cd opt/kde/lib ; ln -sf libgpgme++-pth.so.2.0.2 libgpgme++-pth.so.2 )
( cd opt/kde/lib ; rm -rf libgpgme++-pth.so )
( cd opt/kde/lib ; ln -sf libgpgme++-pth.so.2 libgpgme++-pth.so )
( cd opt/kde/lib ; rm -rf libqgpgme.so.1 )
( cd opt/kde/lib ; ln -sf libqgpgme.so.1.0.1 libqgpgme.so.1 )
( cd opt/kde/lib ; rm -rf libqgpgme.so )
( cd opt/kde/lib ; ln -sf libqgpgme.so.1 libqgpgme.so )
( cd opt/kde/lib ; rm -rf libkmime.so.4 )
( cd opt/kde/lib ; ln -sf libkmime.so.4.2.0 libkmime.so.4 )
( cd opt/kde/lib ; rm -rf libkmime.so )
( cd opt/kde/lib ; ln -sf libkmime.so.4 libkmime.so )
( cd opt/kde/lib ; rm -rf libakonadi-kde.so.4 )
( cd opt/kde/lib ; ln -sf libakonadi-kde.so.4.2.0 libakonadi-kde.so.4 )
( cd opt/kde/lib ; rm -rf libakonadi-kde.so )
( cd opt/kde/lib ; ln -sf libakonadi-kde.so.4 libakonadi-kde.so )
( cd opt/kde/lib ; rm -rf libakonadi-kabc.so.4 )
( cd opt/kde/lib ; ln -sf libakonadi-kabc.so.4.2.0 libakonadi-kabc.so.4 )
( cd opt/kde/lib ; rm -rf libakonadi-kabc.so )
( cd opt/kde/lib ; ln -sf libakonadi-kabc.so.4 libakonadi-kabc.so )
( cd opt/kde/lib ; rm -rf libakonadi-kmime.so.4 )
( cd opt/kde/lib ; ln -sf libakonadi-kmime.so.4.2.0 libakonadi-kmime.so.4 )
( cd opt/kde/lib ; rm -rf libakonadi-kmime.so )
( cd opt/kde/lib ; ln -sf libakonadi-kmime.so.4 libakonadi-kmime.so )
( cd opt/kde/lib ; rm -rf libkabc.so.4 )
( cd opt/kde/lib ; ln -sf libkabc.so.4.2.0 libkabc.so.4 )
( cd opt/kde/lib ; rm -rf libkabc.so )
( cd opt/kde/lib ; ln -sf libkabc.so.4 libkabc.so )
( cd opt/kde/lib ; rm -rf libkabc_file_core.so.4 )
( cd opt/kde/lib ; ln -sf libkabc_file_core.so.4.2.0 libkabc_file_core.so.4 )
( cd opt/kde/lib ; rm -rf libkabc_file_core.so )
( cd opt/kde/lib ; ln -sf libkabc_file_core.so.4 libkabc_file_core.so )
( cd opt/kde/lib ; rm -rf libkblog.so.4 )
( cd opt/kde/lib ; ln -sf libkblog.so.4.2.0 libkblog.so.4 )
( cd opt/kde/lib ; rm -rf libkblog.so )
( cd opt/kde/lib ; ln -sf libkblog.so.4 libkblog.so )
( cd opt/kde/lib ; rm -rf libkcal.so.4 )
( cd opt/kde/lib ; ln -sf libkcal.so.4.2.0 libkcal.so.4 )
( cd opt/kde/lib ; rm -rf libkcal.so )
( cd opt/kde/lib ; ln -sf libkcal.so.4 libkcal.so )
( cd opt/kde/lib ; rm -rf libkimap.so.4 )
( cd opt/kde/lib ; ln -sf libkimap.so.4.2.0 libkimap.so.4 )
( cd opt/kde/lib ; rm -rf libkimap.so )
( cd opt/kde/lib ; ln -sf libkimap.so.4 libkimap.so )
( cd opt/kde/lib ; rm -rf libkldap.so.4 )
( cd opt/kde/lib ; ln -sf libkldap.so.4.2.0 libkldap.so.4 )
( cd opt/kde/lib ; rm -rf libkldap.so )
( cd opt/kde/lib ; ln -sf libkldap.so.4 libkldap.so )
( cd opt/kde/lib ; rm -rf libkpimidentities.so.4 )
( cd opt/kde/lib ; ln -sf libkpimidentities.so.4.2.0 libkpimidentities.so.4 )
( cd opt/kde/lib ; rm -rf libkpimidentities.so )
( cd opt/kde/lib ; ln -sf libkpimidentities.so.4 libkpimidentities.so )
( cd opt/kde/lib ; rm -rf libkpimutils.so.4 )
( cd opt/kde/lib ; ln -sf libkpimutils.so.4.2.0 libkpimutils.so.4 )
( cd opt/kde/lib ; rm -rf libkpimutils.so )
( cd opt/kde/lib ; ln -sf libkpimutils.so.4 libkpimutils.so )
( cd opt/kde/lib ; rm -rf libkresources.so.4 )
( cd opt/kde/lib ; ln -sf libkresources.so.4.2.0 libkresources.so.4 )
( cd opt/kde/lib ; rm -rf libkresources.so )
( cd opt/kde/lib ; ln -sf libkresources.so.4 libkresources.so )
( cd opt/kde/lib ; rm -rf libktnef.so.4 )
( cd opt/kde/lib ; ln -sf libktnef.so.4.2.0 libktnef.so.4 )
( cd opt/kde/lib ; rm -rf libktnef.so )
( cd opt/kde/lib ; ln -sf libktnef.so.4 libktnef.so )
( cd opt/kde/lib ; rm -rf libkxmlrpcclient.so.4 )
( cd opt/kde/lib ; ln -sf libkxmlrpcclient.so.4.2.0 libkxmlrpcclient.so.4 )
( cd opt/kde/lib ; rm -rf libkxmlrpcclient.so )
( cd opt/kde/lib ; ln -sf libkxmlrpcclient.so.4 libkxmlrpcclient.so )
( cd opt/kde/lib ; rm -rf libmailtransport.so.4 )
( cd opt/kde/lib ; ln -sf libmailtransport.so.4.2.0 libmailtransport.so.4 )
( cd opt/kde/lib ; rm -rf libmailtransport.so )
( cd opt/kde/lib ; ln -sf libmailtransport.so.4 libmailtransport.so )
( cd opt/kde/lib ; rm -rf libsyndication.so.4 )
( cd opt/kde/lib ; ln -sf libsyndication.so.4.2.0 libsyndication.so.4 )
( cd opt/kde/lib ; rm -rf libsyndication.so )
( cd opt/kde/lib ; ln -sf libsyndication.so.4 libsyndication.so )
( cd opt/kde/share/doc/HTML/en/kcontrol/kresources ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kresources ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/imap ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/imap ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/ldap ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/ldap ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/nntp ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/nntp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/pop3 ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/pop3 ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/smtp ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/smtp ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> kdepimlibs-4.3.3-i586-P2.tgz: install/doinst.sh <==
( cd opt/kde/share/doc/HTML/en/kcontrol/kresources ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcontrol/kresources ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/imap ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/imap ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/ldap ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/ldap ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/nntp ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/nntp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/pop3 ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/pop3 ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kioslave/smtp ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kioslave/smtp ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/lib ; rm -rf libgpgme++.so.2 )
( cd opt/kde/lib ; ln -sf libgpgme++.so.2.2.1 libgpgme++.so.2 )
( cd opt/kde/lib ; rm -rf libgpgme++.so )
( cd opt/kde/lib ; ln -sf libgpgme++.so.2 libgpgme++.so )
( cd opt/kde/lib ; rm -rf libgpgme++-pthread.so.2 )
( cd opt/kde/lib ; ln -sf libgpgme++-pthread.so.2.2.1 libgpgme++-pthread.so.2 )
( cd opt/kde/lib ; rm -rf libgpgme++-pthread.so )
( cd opt/kde/lib ; ln -sf libgpgme++-pthread.so.2 libgpgme++-pthread.so )
( cd opt/kde/lib ; rm -rf libgpgme++-pth.so.2 )
( cd opt/kde/lib ; ln -sf libgpgme++-pth.so.2.2.1 libgpgme++-pth.so.2 )
( cd opt/kde/lib ; rm -rf libgpgme++-pth.so )
( cd opt/kde/lib ; ln -sf libgpgme++-pth.so.2 libgpgme++-pth.so )
( cd opt/kde/lib ; rm -rf libqgpgme.so.1 )
( cd opt/kde/lib ; ln -sf libqgpgme.so.1.0.1 libqgpgme.so.1 )
( cd opt/kde/lib ; rm -rf libqgpgme.so )
( cd opt/kde/lib ; ln -sf libqgpgme.so.1 libqgpgme.so )
( cd opt/kde/lib ; rm -rf libakonadi-kde.so.4 )
( cd opt/kde/lib ; ln -sf libakonadi-kde.so.4.3.0 libakonadi-kde.so.4 )
( cd opt/kde/lib ; rm -rf libakonadi-kde.so )
( cd opt/kde/lib ; ln -sf libakonadi-kde.so.4 libakonadi-kde.so )
( cd opt/kde/lib ; rm -rf libakonadi-kabc.so.4 )
( cd opt/kde/lib ; ln -sf libakonadi-kabc.so.4.3.0 libakonadi-kabc.so.4 )
( cd opt/kde/lib ; rm -rf libakonadi-kabc.so )
( cd opt/kde/lib ; ln -sf libakonadi-kabc.so.4 libakonadi-kabc.so )
( cd opt/kde/lib ; rm -rf libakonadi-kmime.so.4 )
( cd opt/kde/lib ; ln -sf libakonadi-kmime.so.4.3.0 libakonadi-kmime.so.4 )
( cd opt/kde/lib ; rm -rf libakonadi-kmime.so )
( cd opt/kde/lib ; ln -sf libakonadi-kmime.so.4 libakonadi-kmime.so )
( cd opt/kde/lib ; rm -rf libkabc.so.4 )
( cd opt/kde/lib ; ln -sf libkabc.so.4.3.0 libkabc.so.4 )
( cd opt/kde/lib ; rm -rf libkabc.so )
( cd opt/kde/lib ; ln -sf libkabc.so.4 libkabc.so )
( cd opt/kde/lib ; rm -rf libkabc_file_core.so.4 )
( cd opt/kde/lib ; ln -sf libkabc_file_core.so.4.3.0 libkabc_file_core.so.4 )
( cd opt/kde/lib ; rm -rf libkabc_file_core.so )
( cd opt/kde/lib ; ln -sf libkabc_file_core.so.4 libkabc_file_core.so )
( cd opt/kde/lib ; rm -rf libkblog.so.4 )
( cd opt/kde/lib ; ln -sf libkblog.so.4.3.0 libkblog.so.4 )
( cd opt/kde/lib ; rm -rf libkblog.so )
( cd opt/kde/lib ; ln -sf libkblog.so.4 libkblog.so )
( cd opt/kde/lib ; rm -rf libkcal.so.4 )
( cd opt/kde/lib ; ln -sf libkcal.so.4.3.0 libkcal.so.4 )
( cd opt/kde/lib ; rm -rf libkcal.so )
( cd opt/kde/lib ; ln -sf libkcal.so.4 libkcal.so )
( cd opt/kde/lib ; rm -rf libkholidays.so.4 )
( cd opt/kde/lib ; ln -sf libkholidays.so.4.3.0 libkholidays.so.4 )
( cd opt/kde/lib ; rm -rf libkholidays.so )
( cd opt/kde/lib ; ln -sf libkholidays.so.4 libkholidays.so )
( cd opt/kde/lib ; rm -rf libkimap.so.4 )
( cd opt/kde/lib ; ln -sf libkimap.so.4.3.0 libkimap.so.4 )
( cd opt/kde/lib ; rm -rf libkimap.so )
( cd opt/kde/lib ; ln -sf libkimap.so.4 libkimap.so )
( cd opt/kde/lib ; rm -rf libkldap.so.4 )
( cd opt/kde/lib ; ln -sf libkldap.so.4.3.0 libkldap.so.4 )
( cd opt/kde/lib ; rm -rf libkldap.so )
( cd opt/kde/lib ; ln -sf libkldap.so.4 libkldap.so )
( cd opt/kde/lib ; rm -rf libkmime.so.4 )
( cd opt/kde/lib ; ln -sf libkmime.so.4.3.0 libkmime.so.4 )
( cd opt/kde/lib ; rm -rf libkmime.so )
( cd opt/kde/lib ; ln -sf libkmime.so.4 libkmime.so )
( cd opt/kde/lib ; rm -rf libkpimidentities.so.4 )
( cd opt/kde/lib ; ln -sf libkpimidentities.so.4.3.0 libkpimidentities.so.4 )
( cd opt/kde/lib ; rm -rf libkpimidentities.so )
( cd opt/kde/lib ; ln -sf libkpimidentities.so.4 libkpimidentities.so )
( cd opt/kde/lib ; rm -rf libkpimutils.so.4 )
( cd opt/kde/lib ; ln -sf libkpimutils.so.4.3.0 libkpimutils.so.4 )
( cd opt/kde/lib ; rm -rf libkpimutils.so )
( cd opt/kde/lib ; ln -sf libkpimutils.so.4 libkpimutils.so )
( cd opt/kde/lib ; rm -rf libkresources.so.4 )
( cd opt/kde/lib ; ln -sf libkresources.so.4.3.0 libkresources.so.4 )
( cd opt/kde/lib ; rm -rf libkresources.so )
( cd opt/kde/lib ; ln -sf libkresources.so.4 libkresources.so )
( cd opt/kde/lib ; rm -rf libktnef.so.4 )
( cd opt/kde/lib ; ln -sf libktnef.so.4.3.0 libktnef.so.4 )
( cd opt/kde/lib ; rm -rf libktnef.so )
( cd opt/kde/lib ; ln -sf libktnef.so.4 libktnef.so )
( cd opt/kde/lib ; rm -rf libkxmlrpcclient.so.4 )
( cd opt/kde/lib ; ln -sf libkxmlrpcclient.so.4.3.0 libkxmlrpcclient.so.4 )
( cd opt/kde/lib ; rm -rf libkxmlrpcclient.so )
( cd opt/kde/lib ; ln -sf libkxmlrpcclient.so.4 libkxmlrpcclient.so )
( cd opt/kde/lib ; rm -rf libmailtransport.so.4 )
( cd opt/kde/lib ; ln -sf libmailtransport.so.4.3.0 libmailtransport.so.4 )
( cd opt/kde/lib ; rm -rf libmailtransport.so )
( cd opt/kde/lib ; ln -sf libmailtransport.so.4 libmailtransport.so )
( cd opt/kde/lib ; rm -rf libmicroblog.so.4 )
( cd opt/kde/lib ; ln -sf libmicroblog.so.4.3.0 libmicroblog.so.4 )
( cd opt/kde/lib ; rm -rf libmicroblog.so )
( cd opt/kde/lib ; ln -sf libmicroblog.so.4 libmicroblog.so )
( cd opt/kde/lib ; rm -rf libkpimtextedit.so.4 )
( cd opt/kde/lib ; ln -sf libkpimtextedit.so.4.3.0 libkpimtextedit.so.4 )
( cd opt/kde/lib ; rm -rf libkpimtextedit.so )
( cd opt/kde/lib ; ln -sf libkpimtextedit.so.4 libkpimtextedit.so )
( cd opt/kde/lib ; rm -rf libsyndication.so.4 )
( cd opt/kde/lib ; ln -sf libsyndication.so.4.3.0 libsyndication.so.4 )
( cd opt/kde/lib ; rm -rf libsyndication.so )
( cd opt/kde/lib ; ln -sf libsyndication.so.4 libsyndication.so )
#%% begin initialize kdepimlibs-4.3.3
/bin/bash /opt/kde/bin/plamo_update_kde.sh
#%% end
